@@ -2,291 +2,6 @@
 <!DOCTYPE TS>
 <TS version="2.0" language="ru">
 <defaultcodec>windows-1251</defaultcodec>
-<context>
-    <name>Details</name>
-    <message>
-        <location filename="../../ui/details.ui" line="+23"/>
-        <source>Information for station</source>
-        <translation>Информация по станции </translation>
-    </message>
-</context>
-<context>
-    <name>MainWindow</name>
-    <message>
-        <location filename="../../ui/mainwindow.ui" line="+148"/>
-        <location line="+444"/>
-        <source>Find</source>
-        <translation>Поиск</translation>
-    </message>
-    <message>
-        <location line="-357"/>
-        <source>Waiting time</source>
-        <translation>Время ожидания</translation>
-    </message>
-    <message>
-        <location line="+39"/>
-        <source>Time to station:</source>
-        <translation>Время до станции:</translation>
-    </message>
-    <message>
-        <location line="+46"/>
-        <source>Description</source>
-        <translation>Описание</translation>
-    </message>
-    <message>
-        <location line="+127"/>
-        <source>&amp;File</source>
-        <translation>&amp;Файл</translation>
-    </message>
-    <message>
-        <location line="+14"/>
-        <source>&amp;Settings</source>
-        <translation>&amp;Настройки</translation>
-    </message>
-    <message>
-        <location line="+4"/>
-        <source>Language</source>
-        <translation>Язык</translation>
-    </message>
-    <message>
-        <location line="+15"/>
-        <source>&amp;View</source>
-        <translation>&amp;Вид</translation>
-    </message>
-    <message>
-        <location line="+11"/>
-        <source>&amp;Info</source>
-        <translation>&amp;Инфо</translation>
-    </message>
-    <message>
-        <location line="+104"/>
-        <source>Ctrl+F</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location line="+15"/>
-        <source>Clear</source>
-        <translation>Очистить</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Alt+Del</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location line="+12"/>
-        <source>Save As...</source>
-        <translation>Сохранить как...</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Ctrl+S</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location line="+12"/>
-        <source>Exit</source>
-        <translation>Выход</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Ctrl+Q</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location line="+9"/>
-        <source>Open</source>
-        <translation>Открыть</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Ctrl+O</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location line="+20"/>
-        <location line="+3"/>
-        <source>Zoom in</source>
-        <translation>Увеличить</translation>
-    </message>
-    <message>
-        <location line="+12"/>
-        <location line="+3"/>
-        <source>Zoom out</source>
-        <translation>Уменьшить</translation>
-    </message>
-    <message>
-        <location line="+14"/>
-        <source>Save scale</source>
-        <translation>Сохранять масштаб</translation>
-    </message>
-    <message>
-        <location line="+12"/>
-        <source>Preference</source>
-        <translation>Дополнительно</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Settings</source>
-        <translation>Настройки</translation>
-    </message>
-    <message>
-        <location line="+14"/>
-        <source>Show time</source>
-        <translation>Показывать время</translation>
-    </message>
-    <message>
-        <location line="+11"/>
-        <source>Show hint</source>
-        <translation>Показывать подсказки</translation>
-    </message>
-    <message>
-        <location line="+18"/>
-        <source>Zoom to fit</source>
-        <translation>Вписать</translation>
-    </message>
-    <message>
-        <location line="+19"/>
-        <source>Save position</source>
-        <translation>Сохранять позицию</translation>
-    </message>
-    <message>
-        <location line="+5"/>
-        <source>Add maps...</source>
-        <translation>Добавить карты...</translation>
-    </message>
-    <message>
-        <location line="+12"/>
-        <source>Screen mode</source>
-        <translation>Режим экрана</translation>
-    </message>
-    <message>
-        <location line="+3"/>
-        <source>Alt+Return</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location line="-28"/>
-        <source>Transliterate</source>
-        <translation>Транслитерация</translation>
-    </message>
-    <message>
-        <location line="-358"/>
-        <source>Routes</source>
-        <translation>Маршруты</translation>
-    </message>
-    <message>
-        <location line="+338"/>
-        <source>About...</source>
-        <translation>О программе...</translation>
-    </message>
-    <message>
-        <location filename="../../src/mainwindow.cpp" line="+450"/>
-        <source>Open file</source>
-        <translation>Открыть файл</translation>
-    </message>
-    <message>
-        <location line="+0"/>
-        <source>Map</source>
-        <translation>Карта</translation>
-    </message>
-    <message>
-        <source>Save file</source>
-        <translation>Сохранить файл</translation>
-    </message>
-    <message>
-        <location line="+110"/>
-        <source>Unknown author</source>
-        <translation>Неизвестный автор</translation>
-    </message>
-    <message>
-        <location line="-21"/>
-        <source>About</source>
-        <translation>О программе</translation>
-    </message>
-    <message>
-        <location line="-358"/>
-        <source>Help</source>
-        <translation>Помощь</translation>
-    </message>
-    <message>
-        <location line="+380"/>
-        <source>transit system map</source>
-        <translation>карта транспортной системы</translation>
-    </message>
-    <message>
-        <location line="+0"/>
-        <source>Version</source>
-        <translation>Версия</translation>
-    </message>
-    <message>
-        <source>Data files by</source>
-        <translation>Файлы данных предоставил</translation>
-    </message>
-    <message>
-        <location line="+0"/>
-        <source>Author of map file format</source>
-        <translation>Автор формата файла карт</translation>
-    </message>
-    <message>
-        <location line="+1"/>
-        <source>About current map file</source>
-        <translation>О текущем файле карты</translation>
-    </message>
-    <message>
-        <location line="+4"/>
-        <source>Author of translation: Gusak Leonid</source>
-        <translation>Автор перевода: Гусак Леонид</translation>
-    </message>
-    <message>
-        <location line="+20"/>
-        <source>OK</source>
-        <translation>ОК</translation>
-    </message>
-    <message>
-        <location line="+161"/>
-        <source>All</source>
-        <translation>Все</translation>
-    </message>
-    <message>
-        <location line="+0"/>
-        <source>Information</source>
-        <translation>Информация</translation>
-    </message>
-    <message>
-        <location line="+6"/>
-        <source>Categories</source>
-        <translation>Категории</translation>
-    </message>
-    <message>
-        <location line="+224"/>
-        <source>Add maps</source>
-        <translation>Добавление карты</translation>
-    </message>
-    <message>
-        <location line="+0"/>
-        <source>1. Wait until loaded site...
-2. Select map
-3. Save file map here:</source>
-        <translation>1. Дождаться загрузки сайта...
-2. Выбрать карту
-3. Сохранить файл карты:</translation>
-    </message>
-    <message>
-        <source>Author of this map file</source>
-        <translation>Автор этого файла карты</translation>
-    </message>
-    <message>
-        <location line="-415"/>
-        <source>This program uses</source>
-        <translation>Эта программа использует</translation>
-    </message>
-    <message>
-        <location line="+1"/>
-        <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
-        <translation>Эта программа распространяется в надежде, что она будет полезной, но БЕЗ ВСЯКИХ ГАРАНТИЙ, в том числе подразумеваемых гарантий ТОВАРНОГО СОСТОЯНИЯ ПРИ ПРОДАЖЕ и ГОДНОСТИ ДЛЯ ОПРЕДЕЛЁННОГО ПРИМЕНЕНИЯ. Смотрите Стандартную Общественную Лицензию GNU для получения дополнительной информации.</translation>
-    </message>
-</context>
 <context>
     <name>QColorDialog</name>
     <message>
@@ -583,6 +298,281 @@
         <translation>Выбор шрифта</translation>
     </message>
 </context>
+
+<context>
+    <name>Details</name>
+    <message>
+        <location filename="../../ui/details.ui" line="+23"/>
+        <source>Information for station</source>
+        <translation>Информация по станции </translation>
+    </message>
+</context>
+<context>
+    <name>MainWindow</name>
+    <message>
+        <location filename="../../ui/mainwindow.ui" line="+148"/>
+        <location line="+453"/>
+        <source>Find</source>
+        <translation>Поиск</translation>
+    </message>
+    <message>
+        <location line="-360"/>
+        <source>Waiting time</source>
+        <translation>Время ожидания</translation>
+    </message>
+    <message>
+        <location line="+42"/>
+        <source>Time to station:</source>
+        <translation>Время до станции:</translation>
+    </message>
+    <message>
+        <location line="+46"/>
+        <source>Description</source>
+        <translation>Описание</translation>
+    </message>
+    <message>
+        <location line="+127"/>
+        <source>&amp;File</source>
+        <translation>&amp;Файл</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>&amp;Settings</source>
+        <translation>&amp;Настройки</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Language</source>
+        <translation>Язык</translation>
+    </message>
+    <message>
+        <location line="+15"/>
+        <source>&amp;View</source>
+        <translation>&amp;Вид</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <source>&amp;Info</source>
+        <translation>&amp;Инфо</translation>
+    </message>
+    <message>
+        <location line="+104"/>
+        <source>Ctrl+F</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+15"/>
+        <source>Clear</source>
+        <translation>Очистить</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Alt+Del</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Save As...</source>
+        <translation>Сохранить как...</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+S</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Exit</source>
+        <translation>Выход</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+Q</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+9"/>
+        <source>Open</source>
+        <translation>Открыть</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ctrl+O</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+20"/>
+        <location line="+3"/>
+        <source>Zoom in</source>
+        <translation>Увеличить</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <location line="+3"/>
+        <source>Zoom out</source>
+        <translation>Уменьшить</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>Save scale</source>
+        <translation>Сохранять масштаб</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Preference</source>
+        <translation>Дополнительно</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Settings</source>
+        <translation>Настройки</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>Show time</source>
+        <translation>Показывать время</translation>
+    </message>
+    <message>
+        <location line="+11"/>
+        <source>Show hint</source>
+        <translation>Показывать подсказки</translation>
+    </message>
+    <message>
+        <location line="+18"/>
+        <source>Zoom to fit</source>
+        <translation>Вписать</translation>
+    </message>
+    <message>
+        <location line="+19"/>
+        <source>Save position</source>
+        <translation>Сохранять позицию</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Add maps...</source>
+        <translation>Добавить карты...</translation>
+    </message>
+    <message>
+        <location line="+12"/>
+        <source>Screen mode</source>
+        <translation>Режим экрана</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Alt+Return</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="-28"/>
+        <source>Transliterate</source>
+        <translation>Транслитерация</translation>
+    </message>
+    <message>
+        <location line="-358"/>
+        <source>Routes</source>
+        <translation>Маршруты</translation>
+    </message>
+    <message>
+        <location line="+338"/>
+        <source>About...</source>
+        <translation>О программе...</translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="+372"/>
+        <source>Open file</source>
+        <translation>Открыть файл</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Map</source>
+        <translation>Карта</translation>
+    </message>
+    <message>
+        <source>Save file</source>
+        <translation type="obsolete">Сохранить файл</translation>
+    </message>
+    <message>
+        <source>Unknown author</source>
+        <translation type="obsolete">Неизвестный автор</translation>
+    </message>
+    <message>
+        <source>About</source>
+        <translation type="obsolete">О программе</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation type="obsolete">Помощь</translation>
+    </message>
+    <message>
+        <source>transit system map</source>
+        <translation type="obsolete">карта транспортной системы</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation type="obsolete">Версия</translation>
+    </message>
+    <message>
+        <source>Data files by</source>
+        <translation type="obsolete">Файлы данных предоставил</translation>
+    </message>
+    <message>
+        <source>Author of map file format</source>
+        <translation type="obsolete">Автор формата файла карт</translation>
+    </message>
+    <message>
+        <source>About current map file</source>
+        <translation type="obsolete">О текущем файле карты</translation>
+    </message>
+    <message>
+        <source>Author of translation: Gusak Leonid</source>
+        <translation type="obsolete">Автор перевода: Гусак Леонид</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="obsolete">ОК</translation>
+    </message>
+    <message>
+        <location line="+207"/>
+        <source>All</source>
+        <translation>Все</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Information</source>
+        <translation>Информация</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>Categories</source>
+        <translation>Категории</translation>
+    </message>
+    <message>
+        <location line="+226"/>
+        <source>Add maps</source>
+        <translation>Добавление карты</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>1. Wait until loaded site...
+2. Select map
+3. Save file map here:</source>
+        <translation>1. Дождаться загрузки сайта...
+2. Выбрать карту
+3. Сохранить файл карты:</translation>
+    </message>
+    <message>
+        <source>Author of this map file</source>
+        <translation type="obsolete">Автор этого файла карты</translation>
+    </message>
+    <message>
+        <source>This program uses</source>
+        <translation type="obsolete">Эта программа использует</translation>
+    </message>
+    <message>
+        <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
+        <translation type="obsolete">Эта программа распространяется в надежде, что она будет полезной, но БЕЗ ВСЯКИХ ГАРАНТИЙ, в том числе подразумеваемых гарантий ТОВАРНОГО СОСТОЯНИЯ ПРИ ПРОДАЖЕ и ГОДНОСТИ ДЛЯ ОПРЕДЕЛЁННОГО ПРИМЕНЕНИЯ. Смотрите Стандартную Общественную Лицензию GNU для получения дополнительной информации.</translation>
+    </message>
+</context>
 <context>
     <name>Settings</name>
     <message>
@@ -591,22 +581,22 @@
         <translation>Настройки</translation>
     </message>
     <message>
-        <location line="+38"/>
+        <location line="+68"/>
         <source>Interface</source>
         <translation>Интерфейс</translation>
     </message>
     <message>
-        <location line="+27"/>
+        <location line="+39"/>
         <source>Custom font and style for station</source>
         <translation>Настраиваемый шрифт для станции</translation>
     </message>
     <message>
-        <location line="+10"/>
+        <location line="+13"/>
         <source>Font and style for station name</source>
         <translation>Шрифт и стиль названий станций</translation>
     </message>
     <message>
-        <location line="+73"/>
+        <location line="+66"/>
         <source>Font...</source>
         <translation>Шрифт...</translation>
     </message>
@@ -626,21 +616,26 @@
         <translation>Масштаб интерфейса</translation>
     </message>
     <message>
-        <location line="+150"/>
+        <location line="+114"/>
+        <source>Caching graphics</source>
+        <translation>Кешировать графику</translation>
+    </message>
+    <message>
+        <location line="+53"/>
         <source>Simple graphics for transfers*</source>
         <translation>Упрощённая графика для переходов*</translation>
     </message>
     <message>
         <source>Background</source>
-        <translation>Фон</translation>
+        <translation type="obsolete">Фон</translation>
     </message>
     <message>
-        <location filename="../../src/settings.cpp" line="+27"/>
+        <location filename="../../src/settings.cpp" line="+46"/>
         <source>Color...</source>
         <translation>Цвет...</translation>
     </message>
     <message>
-        <location filename="../../ui/settings.ui" line="-303"/>
+        <location filename="../../ui/settings.ui" line="-320"/>
         <source>Shadow</source>
         <translation>Тень</translation>
     </message>
@@ -671,15 +666,15 @@
     </message>
     <message>
         <source>Full screen mode</source>
-        <translation>Полноэкранный режим</translation>
+        <translation type="obsolete">Полноэкранный режим</translation>
     </message>
     <message>
-        <location line="+46"/>
+        <location line="+53"/>
         <source>Performance</source>
         <translation>Производительность</translation>
     </message>
     <message>
-        <location line="+27"/>
+        <location line="+37"/>
         <source>Show time to the stations</source>
         <translation>Показывать время до станций</translation>
     </message>
@@ -700,7 +695,7 @@
     </message>
     <message>
         <source>Simple graphics for transfers</source>
-        <translation>Упрощённая графика для переходов</translation>
+        <translation type="obsolete">Упрощённая графика для переходов</translation>
     </message>
     <message>
         <location line="+52"/>
@@ -726,12 +721,12 @@
 <context>
     <name>TMapView</name>
     <message>
-        <location filename="../../src/mapview/mapview.cpp" line="+98"/>
+        <location filename="../../src/mapview/mapview.cpp" line="+102"/>
         <source>Information</source>
         <translation>Информация</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+4"/>
         <source>Start</source>
         <translation>Начальная</translation>
     </message>
@@ -741,7 +736,7 @@
         <translation>Конечная</translation>
     </message>
     <message>
-        <location line="+162"/>
+        <location line="+225"/>
         <source>Day</source>
         <translation>День</translation>
     </message>
@@ -761,14 +756,14 @@
         <translation>Час-пик</translation>
     </message>
     <message>
-        <location line="+107"/>
+        <location line="+115"/>
         <source>Cannot open file mapping:
 %1</source>
         <translation>Невозможно открыть файл карты:
 %1</translation>
     </message>
     <message>
-        <location line="+1034"/>
+        <location line="+1058"/>
         <source>line</source>
         <translation>линия</translation>
     </message>
@@ -788,34 +783,35 @@
         <translation>Переход на станцию:</translation>
     </message>
     <message>
-        <location line="+230"/>
+        <location line="+254"/>
         <source>Save file</source>
         <translation>Сохранить файл</translation>
     </message>
     <message>
         <source>All</source>
-        <translation>Все</translation>
+        <translation type="obsolete">Все</translation>
     </message>
     <message>
         <source>Categories</source>
-        <translation>Категории</translation>
+        <translation type="obsolete">Категории</translation>
     </message>
     <message>
         <source>Transfer at station:</source>
-        <translation>Переход на станцию:</translation>
+        <translation type="obsolete">Переход на станцию:</translation>
     </message>
     <message>
-        <location line="-225"/>
+        <location line="-249"/>
         <source>Final station:</source>
         <translation>Конечная станция:</translation>
     </message>
     <message>
+        <location line="+7"/>
         <location line="+5"/>
         <source>st.</source>
         <translation>станц.</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+3"/>
         <source>Travel time</source>
         <translation>Время в пути</translation>
     </message>
@@ -833,7 +829,7 @@
 <context>
     <name>UnZip</name>
     <message>
-        <location filename="../../src/zip/unzip.cpp" line="+245"/>
+        <location filename="../../src/zip/unzip.cpp" line="+1138"/>
         <source>ZIP operation completed successfully.</source>
         <translation>Операции с ZIP файлом закончены успешно.</translation>
     </message>
@@ -918,4 +914,118 @@
         <translation>Неизвестная ошибка.</translation>
     </message>
 </context>
+<context>
+    <name>TMobileUi</name>
+    <message>
+        <location filename="../../src/mobileui.cpp" line="+43"/>
+        <source>Help</source>
+        <translation>Помощь</translation>
+    </message>
+</context>
+<context>
+    <name>About</name>
+    <message>
+        <location filename="../../src/about.h" line="+26"/>
+        <source>About</source>
+        <translation>О программе</translation>
+    </message>
+    <message>
+        <location line="+35"/>
+        <source>Unknown author</source>
+        <translation>Неизвестный автор</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>transit system map</source>
+        <translation>карта транспортной системы</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Version</source>
+        <translation>Версия</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Author of map file format</source>
+        <translation>Автор формата файла карт</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>About current map file</source>
+        <translation>О текущем файле карты</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>This program uses</source>
+        <translation>Эта программа использует</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
+        <translation>Эта программа распространяется в надежде, что она будет полезной, но БЕЗ ВСЯКИХ ГАРАНТИЙ, в том числе подразумеваемых гарантий ТОВАРНОГО СОСТОЯНИЯ ПРИ ПРОДАЖЕ и ГОДНОСТИ ДЛЯ ОПРЕДЕЛЁННОГО ПРИМЕНЕНИЯ. Смотрите Стандартную Общественную Лицензию GNU для получения дополнительной информации.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Author of translation: Gusak Leonid</source>
+        <translation>Автор перевода: Гусак Леонид</translation>
+    </message>
+    <message>
+        <location line="+21"/>
+        <source>OK</source>
+        <translation>ОК</translation>
+    </message>
+</context>
+<context>
+    <name>Zip</name>
+    <message>
+        <location filename="../../src/zip/zip.cpp" line="+1205"/>
+        <source>ZIP operation completed successfully.</source>
+        <translation>Операции с ZIP файлом закончены успешно.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Failed to initialize or load zlib library.</source>
+        <translation>Невозможно инициализировать или загрузить библиотеку zlib.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>zlib library error.</source>
+        <translation>Ошибка библиотеки zlib.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Unable to create or open file.</source>
+        <translation>Невозможно создать или открыть файл.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>No archive has been created yet.</source>
+        <translation>Архив не был создан.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>File or directory does not exist.</source>
+        <translation>Отсутствует файл или директория.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>File read error.</source>
+        <translation>Ошибка чтения файла.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>File write error.</source>
+        <translation>Ошибка записи файла.</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>File seek error.</source>
+        <translation>Ошибка поиска в файле.</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Unknown error.</source>
+        <translation>Неизвестная ошибка.</translation>
+    </message>
+</context>
 </TS>
