@@ -152,8 +152,6 @@ MainWindow::MainWindow(QWidget *parent) :
   connect(&charm,SIGNAL(finished()),map,SLOT(mapStopDragging()));
  }
 
- loadSettings();
-
  ui->toolBar->setIconSize(QSize(Config.appIconSize,Config.appIconSize));
  QSplitter *splitter = new QSplitter;
  splitter->addWidget(ui->dock);
@@ -165,6 +163,9 @@ MainWindow::MainWindow(QWidget *parent) :
  setCentralWidget(splitter);
 
 
+ loadSettings();
+
+
 #ifdef Q_OS_SYMBIAN
  // Remove context menu from all widgets
  QWidgetList widgets=QApplication::allWidgets();
@@ -380,7 +381,7 @@ void MainWindow::on_mOpen_triggered()
  if(Completer) delete Completer;
  map->loadMap(fileName);
  map->fitMap();
- map->viewport()->update();
+ //map->viewport()->update();
  ui->eSearch->setText("");
  Completer= new TCompleter(map,ui->eSearch);
 //qDebug() << "Load time: " << testTimer.elapsed();
@@ -444,82 +445,6 @@ void MainWindow::on_mAbout_triggered()
  if(MobileVersion)
       a->showMaximized();
  else a->exec();
-// QDialog *About = new QDialog(this);
-// QPushButton OK(About);
-// QHBoxLayout HLayout;
-// QVBoxLayout VLayout;
-// QLabel Logo(About);
-// QTextBrowser Info(About);
-
-//#ifdef Q_WS_MAEMO_5
-// About->setAttribute(Qt::WA_Maemo5StackedWindow);
-// About->setWindowFlags(Qt::Window);
-// About->setAttribute(Qt::WA_Maemo5AutoOrientation);
-//#else
-// FlickCharm fcharm;
-// fcharm.activateOn(&Info);
-//#endif
-// //About->setWindowFlags(Qt::Tool);
-// About->setWindowFlags(About->windowFlags() & (~Qt::WindowContextHelpButtonHint));
-// About->setFixedWidth(500);
-// About->setMinimumHeight(155);
-// About->setFixedHeight(400);
-// About->setWindowTitle(tr("About")+" qMetro");
-// About->setLayout(&HLayout);
-
-// HLayout.addWidget(&Logo);
-// //HLayout.setContentsMargins(5,5,0,0);
-// HLayout.setAlignment(&Logo,Qt::AlignTop);
-// Logo.setFixedWidth(64);
-// Logo.setContentsMargins(0,5,0,0);
-// Logo.setPixmap(QPixmap(":/qmetro.png"));
-
-// QString hr=QString("<p><table height=2 width=100% bgcolor=%1><tr><td></table></p>")
-//            .arg(palette().color(QPalette::Mid).name());
-// QString text=
-// QString("<p><font size=6><b>qMetro</b></font> - %4.</p>"
-//         "<p>%5 %1 &copy; 2011 <a href=\"mailto:guuleon@gmail.com\">Gusak Leonid</a>"
-//         " - <a href=\"http://qmetro.sf.net\">qmetro.sf.net</a></p>"
-//         "<p>%6: <a href=\"mailto:Boris@pMetro.su\">Muradov Boris</a>"
-//         " - <a href=\"%10\">pMetro</a></p>"
-//         "<p>%11</p>"
-//         "<hr><b>%7:</b>"
-//         "<p>%3</p>"
-//         "<hr><b>%8:</b><ul type=\"circle\"><li>&nbsp;Qt %2<li>&nbsp;zlib + OSDaB</ul>"
-//         "<hr>%9")
-// .arg(VERSION).arg(QT_VERSION_STR).arg((map->params.mapAuthors.isEmpty() ? tr("Unknown author"):map->params.mapAuthors)) // 1
-// .arg(tr("transit system map")).arg(tr("Version")).arg(tr("Author of map file format")) // 3
-// .arg(tr("About current map file")).arg(tr("This program uses")) // 6
-// .arg(tr("This program is distributed in the hope that it will be useful, "
-//         "but WITHOUT ANY WARRANTY; without even the implied warranty of "
-//         "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-//         "GNU General Public License for more details.")).arg(URL_MAPS).arg(tr("Author of translation: Gusak Leonid"));
-
-// text.replace("<hr>",hr);
-// HLayout.addLayout(&VLayout);
-// VLayout.addWidget(&Info);
-// QPalette pal = Info.palette();
-// pal.setBrush(QPalette::Base, Qt::transparent);
-// pal.setColor(QPalette::Text,palette().color(QPalette::Text));
-// Info.setPalette(pal);
-// Info.setAttribute(Qt::WA_NoSystemBackground,1);
-// Info.setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
-// Info.setOpenExternalLinks(1);
-// Info.setReadOnly(1);
-// Info.setFrameShape(QFrame::NoFrame);
-// Info.setText(text);
-// //Info.setStyleSheet("hr{color:palette(text)");
-
-// VLayout.addWidget(&OK);
-// VLayout.setAlignment(&OK,Qt::AlignRight);
-// OK.setText(tr("OK"));
-// OK.setDefault(1);
-// OK.setMaximumWidth(75);
-// connect(&OK,SIGNAL(pressed()),About,SLOT(accept()));
-
-// if(MobileVersion)
-//      About->showFullScreen();
-// else About->exec();
 }
 
 void MainWindow::on_mPreference_triggered()
@@ -695,9 +620,9 @@ void MainWindow::closeEvent(QCloseEvent * e)
       cfg.setValue(key,QPoint(map->horizontalScrollBar()->value(),map->verticalScrollBar()->value()));
  else cfg.remove(key);
  if(MobileVersion) cfg.setValue("Styles",TOOLBAR_STYLE);
-
+ cfg.endGroup();
  if(AppConfig.value(igOther).value(ikMCleanCache).toInt()) removeDir(cachePath);
-
+ else
  if(map->config.enableCaching && !QFile::exists(map->params.mapPath+".cache"))
   map->CachedMap->save(map->params.mapPath+".cache","PNG");
  map->clearMap();
@@ -756,12 +681,12 @@ void applySettings(const IniSettingMap &settings)
   }
  }
 
- map->applyConfig(); // + load last map
-
  if(map->config.enableCustomFont)
       map->params.nodeFont=nodeFont;
  else map->params.nodeFont=map->params.nodeFontDefault;
 
+ map->applyConfig(); // + load last map
+
  //map->show();
 }
 
@@ -899,7 +824,7 @@ void MainWindow::on_mFullScreen_toggled(bool checked)
 
 void MainWindow::setScaleForUi(qreal UiScale)
 {
- if(UiScale<=0.0) return;
+ if(UiScale<=qreal(0.0)) return;
 
  QFont font=Config.appFont;
  Config.appIconSize=ICONSIZE*UiScale;
