@@ -14,7 +14,7 @@ TMapElement::TMapElement(ElementType type,QRectF rect,QString text)
  eType=type;
  eRect=rect;
  setZValue(1);
- FadeOpacity=0.6;
+ FadeOpacity=qreal(0.6);
  //if(type==elScreen) setEnabled(0);
 
 // setAcceptHoverEvents(0);
@@ -60,7 +60,7 @@ void TMapElement::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWi
 
    if(map->selectedNode.count()) // nodes
    {
-    int width=map->params.nodeWidth*1.3;
+    qreal width=map->params.nodeWidth*qreal(1.3);
     p->setPen(Qt::NoPen);
     p->setBrush(Qt::black);
     foreach(TMapNode *node,map->selectedNode)
@@ -71,19 +71,19 @@ void TMapElement::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWi
    {
     QPainterPath tPath;
     QColor color=QColor(0,0,0,0);
-    int width;
+    qreal width;
     p->setBrush(Qt::NoBrush);
     foreach(TMapEdge *edge, map->selectedEdge)
      if(edge->type==TMapEdge::etTransfer)
      {
-      qreal w=map->params.routeWidth/1.7;
+      qreal w=map->params.routeWidth/qreal(1.7);
       tPath.addEllipse(edge->node[0]->pos(),w,w);
       tPath.addEllipse(edge->node[1]->pos(),w,w);
       tPath.addPath(edge->path);
      }
 
     // black border for transfers
-    p->setPen(QPen(Qt::black,map->params.routeWidth*1.5,Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
+    p->setPen(QPen(Qt::black,map->params.routeWidth*qreal(1.5),Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
     p->drawPath(tPath);
     foreach(TMapEdge *edge, map->selectedEdge)
     {
@@ -95,7 +95,7 @@ void TMapElement::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWi
      else continue;
 
      // black border for lines
-     p->setPen(QPen(Qt::black,width*1.3,Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
+     p->setPen(QPen(Qt::black,width*qreal(1.3),Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
      p->drawPath(edge->path);
      p->setPen(QPen(color,width,Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
      p->drawPath(edge->path);
