@@ -42,6 +42,10 @@ void TMapNode::init()
  int sWidth=Map->params.nodeWidth;
  QRectF r;
  bool leftAlign=0;
+ QPixmap pix(1,1);
+ QPainter p(&pix); // fake
+ p.setFont(Map->params.nodeFont);
+
 
  DisplayName=(Alias.isEmpty() ? Name:Alias);
  if(Map->config.enableTranslit) Map->convertToTranslit(DisplayName);
@@ -65,22 +69,22 @@ void TMapNode::init()
    Vertical=1;
   }
   Align+=Qt::AlignLeft;
-
-  QPixmap pix(NRect90.size());
-  QPainter p(&pix); // fake
   QMatrix matrix;
   QPainterPath pRect;
 
-  p.setFont(Map->params.nodeFont);
   p.drawText(NRect90,Align,DisplayName,&NRect90);
-
   pRect.addRect(NRect90);
   matrix.rotate(90*Vertical);
   pRect=matrix.map(pRect);
   NRect=pRect.boundingRect().toRect();
 
  }else
- if(Rect.center().x()-sWidth>pos().x()) Align+=Qt::AlignLeft; else Align+=Qt::AlignRight;
+ {
+  if(Rect.center().x()-sWidth>pos().x())
+       Align+=Qt::AlignLeft;
+  else Align+=Qt::AlignRight;
+  p.drawText(NRect,Align,DisplayName,&NRect);
+ }
  r=shape().boundingRect();
  prepareGeometryChange();
  NodeWidth=r.width();
@@ -139,7 +143,7 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
 
  if(TypeNode==ntConstruct)
  {
-  p->setPen(QPen(Qt::gray,1));
+  p->setPen(QPen(Route->color,2));
   p->setBrush(Qt::white);
  }else
  if(Map->nodeBeginID==ID)
@@ -157,7 +161,7 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
  if(Map->config.enableWriteTime && Map->nodeBegin && TypeNode!=ntConstruct && Map->mapDistance.count()
     && (!Map->config.enableCaching || (Map->config.enableCaching && Map->state.mapCached)) )
  {
-  int dist=Map->mapDistance[ID];
+  int dist=Map->mapDistance[ID]; // write times
   if(dist<INFINIT)
   {
    QFont f=Map->params.nodeFont;
@@ -195,17 +199,17 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
   {
    p->setBackgroundMode(Qt::TransparentMode);
    p->setPen(Qt::white);
-   p->drawText(TextRect.adjusted(-0.2,-0.2,-0.2,-0.2),Align,DisplayName);
+   p->drawText(TextRect.adjusted(qreal(-0.2),qreal(-0.2),qreal(-0.2),qreal(-0.2)),Align,DisplayName);
 
    p->setPen(Route->color.dark());
-   p->drawText(TextRect.adjusted(0.3,0.3,0.3,0.3),Align,DisplayName);
+   p->drawText(TextRect.adjusted(qreal(0.3),qreal(0.3),qreal(0.3),qreal(0.3)),Align,DisplayName);
   }
 
   if(Map->config.enableCustomFont && Map->config.enableStationShadowColor)
   {
    p->setBackgroundMode((Map->config.enableStationBackColor ? Qt::OpaqueMode:Qt::TransparentMode));
    p->setPen(Map->params.nodeColorShadow);
-   p->drawText(TextRect.adjusted(0.6,0.6,0.6,0.6),Align,DisplayName);
+   p->drawText(TextRect.adjusted(qreal(0.6),qreal(0.6),qreal(0.6),qreal(0.6)),Align,DisplayName);
    p->setBackgroundMode(Qt::TransparentMode);
   }
 
