@@ -227,11 +227,6 @@ void TMapView::drawBackground(QPainter *painter, const QRectF &rect)
     drawPaintCmd(painter,paintMap);
    }
 
-
-
-
-
-
   //qDebug() << testTimer.elapsed();
 
 
@@ -361,7 +356,7 @@ void TMapView::loadMap(QString fileName)
  params.nodeWidth=ini.value("StationDiameter","16").toInt()/2;
  params.nodeConstructWidth=params.nodeWidth*qreal(0.7);
  params.routeWidth=ini.value("LinesWidth","9").toInt();
- if(params.routeWidth/params.nodeWidth>1.8) // some freak map :)
+ if(params.routeWidth/params.nodeWidth>qreal(1.8)) // some freak map :)
   params.routeWidth=params.nodeWidth;
  params.nodeUpperCase=ini.value("UpperCase","1",vtBoolean).toInt();
  params.nodeWordWrap=ini.value("WordWrap","1",vtBoolean).toInt();
@@ -1052,16 +1047,19 @@ void TMapView::loadMapLayers(QString LayerFilesTRP)
     }else // find ")"
     {
      int pos=str.indexOf(")");
-     QString edgeCost=cost.value(i);
+     eCost=cost.value(i);
      if(pos!=-1)
      {
+      if(eCost.indexOf(")")==-1) // when "()", but need "(,,)"
+      {
+       cost.insert(i,"");
+       eCost="";
+      } else eCost.remove(")");
       str.remove(")");
-      //edgeCost.remove(")");
       sign=0;
      }
      node1=nodeName;
      node2=str;
-     eCost=edgeCost;
      if(eCost.isEmpty()) eCost="0";
     }
     if(!sign && eCost.isEmpty() && i<name.count()-1 && name.value(i+1).indexOf("(")==-1)
@@ -1071,7 +1069,7 @@ void TMapView::loadMapLayers(QString LayerFilesTRP)
      eCost=cost.value(i);
     }
     if(node2.isEmpty()) continue;
-    eCost.remove("("); eCost.remove(")");
+    eCost.remove("("); //eCost.remove(")");
 
     node1=map.toStringList(node1).at(0); // quoter chop
     node2=map.toStringList(node2).at(0);
@@ -1153,7 +1151,7 @@ void TMapView::addLayerToPaintCmd(TMapLayer *mapLayer,QList<TPaintCmd> &paintCmd
  TPaintCmd tCmd;
  QPainterPath tPath;
 
- int tWidth=params.routeWidth;
+ qreal tWidth=params.routeWidth;
 // tCmd.brush=QBrush(Qt::SolidPattern);
 // tCmd.type=dtBrushColor;
 // paintCmd << tCmd;
@@ -1277,7 +1275,7 @@ void TMapView::addLayerToPaintCmd(TMapLayer *mapLayer,QList<TPaintCmd> &paintCmd
 
   tCmd = TPaintCmd();
 
-  tCmd.pen=QPen(params.mapColorBack.lighter(150),tWidth*1.2,Qt::SolidLine,Qt::SquareCap,Qt::MiterJoin);
+  tCmd.pen=QPen(params.mapColorBack.lighter(150),tWidth*qreal(1.2),Qt::SolidLine,Qt::SquareCap,Qt::MiterJoin);
   tCmd.type=dtPenColor;
   paintCmd << tCmd;
 
@@ -1301,7 +1299,7 @@ void TMapView::mouseMoveEvent(QMouseEvent *event)
   }
   state.mapDragging=1;
  }
- if(TimerPopup.isActive() && QLineF(nodeClickPos,event->pos()).length()>8) TimerPopup.stop();
+ if(TimerPopup.isActive() && QLineF(nodeClickPos,event->pos()).length()>qreal(8.0)) TimerPopup.stop();
 }
 
 //void TMapView::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
@@ -1378,6 +1376,7 @@ void TMapView::mouseReleaseEvent(QMouseEvent *event)
   {
    clearTrack();
    if(nodeClick) nodeClick->update();
+   viewport()->update();
   }
   return;
  }
@@ -1430,7 +1429,17 @@ void TMapView::selectedNodesToFront(bool enable)
 
 void TMapView::findTrack(TMapNode *begin,TMapNode *end)
 {
- if(begin==NULL || begin->TypeNode==TMapNode::ntConstruct) return;
+ if(!begin && end)
+ {
+  nodeEndID=end->ID;
+  if(nodeEnd) nodeEnd->update();
+  nodeEnd=end;
+  end->update();
+  return;
+ }
+ if(!begin || begin->TypeNode==TMapNode::ntConstruct ||
+    begin==end || (end && end->TypeNode==TMapNode::ntConstruct)) return;
+ //if(end) if(end->TypeNode==TMapNode::ntConstruct) return;
 
  if(end==NULL) // click node: begin or end
  {
@@ -1445,43 +1454,43 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end)
 
  nodeBeginID=nodeBegin->ID;
  if(nodeEnd) nodeEndID=nodeEnd->ID;
-
- if(nodeBegin) nodeBegin->update();
- if(nodeEnd) nodeEnd->update();
-
+ if(!nodeEnd)mapDistance.clear();
+ viewport()->repaint();
  selectedNodesToFront(0);
 
  // calc distances
- int size=mapGraph.count();
- workGraph.resize(size);
- for(int i=0;i<size;i++)
+ if(nodeClick!=nodeEnd)
  {
-  workGraph[i].resize(size);
-  for(int j=0;j<size;j++)
+  int size=mapGraph.count();
+  workGraph.resize(size);
+  for(int i=0;i<size;i++)
   {
-   if(mapGraph[i][j]) workGraph[i][j]=mapGraph[i][j]->cost;
-   else               workGraph[i][j]=0;
+   workGraph[i].resize(size);
+   for(int j=0;j<size;j++)
+   {
+    if(mapGraph[i][j]) workGraph[i][j]=mapGraph[i][j]->cost;
+    else               workGraph[i][j]=0;
 
-   if(workGraph[i][j] && i==nodeBeginID)
+    if(workGraph[i][j] && i==nodeBeginID)
      workGraph[i][j]+=params.delayMetro*60+mapGraph[i][j]->node[1]->Route->delay.at(params.delayIndex);
 
-   if(workGraph[i][j] && mapGraph[i][j]->type==TMapEdge::etTransfer)
+    if(workGraph[i][j] && mapGraph[i][j]->type==TMapEdge::etTransfer)
      workGraph[i][j]+=+mapGraph[i][j]->node[1]->Route->delay.at(params.delayIndex);
 
+   }
   }
+
+  // for(int i=0;i<workGraph.count();i++)
+  //  if(workGraph[nodeBeginID][i]!=NULL)
+  //   workGraph[nodeBeginID][i]+=param.delayMetro*60;
+
+  dijkstra(nodeBeginID);
+  mapDistance[nodeBeginID]=params.delayMetro*60;
+
+  if(config.enableWriteTime) viewport()->update(); //foreach(TMapNode *node,nodeByID) node->update();
+
  }
-
-// for(int i=0;i<workGraph.count();i++)
-//  if(workGraph[nodeBeginID][i]!=NULL)
-//   workGraph[nodeBeginID][i]+=param.delayMetro*60;
-
- dijkstra(nodeBeginID);
- mapDistance[nodeBeginID]=params.delayMetro*60;
-
- if(config.enableWriteTime) foreach(TMapNode *node,nodeByID) node->update();
-
- if(nodeEnd==NULL)return;
-
+ if(!nodeEnd) return;
  // find track
  QList<int> id;
  int endID=nodeEndID;
@@ -1661,8 +1670,6 @@ void TMapView::applyConfig()
   setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
  }
 
- if(nodeByID.isEmpty() && !config.mapLastFile.isEmpty()) loadMap(config.mapLastFile);
- config.mapLastFile="";
 
   if(config.enableAntialiasing)
        params.nodeFont.setStyleStrategy(QFont::PreferAntialias);
@@ -1680,6 +1687,11 @@ void TMapView::applyConfig()
   QFile::remove(params.mapPath+".cache");
   state.mapCached=0;
  }
+
+ // its last operation - load map with config
+ if(nodeByID.isEmpty() && !config.mapLastFile.isEmpty()) loadMap(config.mapLastFile);
+ config.mapLastFile="";
+
  //viewport()->update();
 }
 
@@ -1760,15 +1772,16 @@ void TMapView::loadNodeInfo(TMapNode *node)
 
 void TMapView::setNodeBegin()
 {
- nodeBegin=nodeClick;
- findTrack(nodeBegin,nodeEnd);
- nodeClick->update();
+ //nodeBegin=nodeClick;
+ findTrack(nodeClick,nodeEnd);
+ //nodeClick->update();
 }
 void TMapView::setNodeEnd()
 {
- nodeEnd=nodeClick;
- findTrack(nodeBegin,nodeEnd);
- nodeClick->update();
+  //nodeEnd=nodeClick;
+ findTrack(nodeBegin,nodeClick);
+
+ //nodeClick->update();
 }
 
 void TMapView::saveToFile()
