@@ -130,8 +130,9 @@ public:
      bool    mapIsVector;
      qreal   mapZoomFactor;
 
-     int    nodeWidth;
+     qreal  nodeWidth;
      qreal  nodeConstructWidth;
+     qreal  routeWidth;
      QFont  nodeFont;    // +UpperCase
      QFont  nodeFontDefault;
      int    nodeFontStyle; // +WordWrap
@@ -140,7 +141,7 @@ public:
      bool   nodeUpperCase;
      bool   nodeWordWrap;
 
-     int routeWidth;
+
 
      QString Transports;
      QString CheckedTransports;
